@@ -2,7 +2,7 @@ package Font::TTF::Mort::Insertion;
 
 =head1 NAME
 
-Font::TTF::Mort::Insertion
+Font::TTF::Mort::Insertion - Insertion Mort subtable for AAT
 
 =head1 METHODS
 
@@ -172,8 +172,18 @@ None known
 
 =head1 AUTHOR
 
-Jonathan Kew L<Jonathan_Kew@sil.org>. See L<Font::TTF::Font> for copyright and
-licensing.
+Jonathan Kew L<Jonathan_Kew@sil.org>. 
+
+
+=head1 LICENSING
+
+Copyright (c) 1998-2013, SIL International (http://www.sil.org) 
+
+This module is released under the terms of the Artistic License 2.0. 
+For details, see the full text of the license in the file LICENSE.
+
+
 
 =cut
 
+
